<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=hac
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => 'دروسکەودەی فشاردریاو سی‌ئێس‌ئێس و جاڤا سکریپتی چە لاو سەری  پەڕەکاۋە چیرو<code>ecrire/</code> و/یا سەرو پەڕەی سەرەكی پەڕیانەكەیۆ',
	'compresseur_slogan' => 'دروسکەردەی فشاردریاو سی‌ئێس‌ئێس و جاڤا سکریپتی',
];
